==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/DownLeftAndUpRightToCenter.md <==
# DownLeftAndUpRightToCenter


```text
fontawesome-6/Solid/DownLeftAndUpRightToCenter
```

```text
include('fontawesome-6/Solid/DownLeftAndUpRightToCenter')
```



| Illustration | DownLeftAndUpRightToCenter |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/DownLeftAndUpRightToCenter.png) | ![illustration for DownLeftAndUpRightToCenter](../../fontawesome-6/Solid/DownLeftAndUpRightToCenter.Local.png) |




## DownLeftAndUpRightToCenter

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element DownLeftAndUpRightToCenter
include('fontawesome-6/Solid/DownLeftAndUpRightToCenter')

' renders the element
DownLeftAndUpRightToCenter('DownLeftAndUpRightToCenter', 'Down Left And Up Right To Center', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element DownLeftAndUpRightToCenter
include('fontawesome-6/Solid/DownLeftAndUpRightToCenter')

' renders the element
DownLeftAndUpRightToCenter('DownLeftAndUpRightToCenter', 'Down Left And Up Right To Center', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/fontawesome-6/Solid/DownLeftAndUpRightToCenter.md <==
# DownLeftAndUpRightToCenter


```text
fontawesome-6/Solid/DownLeftAndUpRightToCenter
```

```text
include('fontawesome-6/Solid/DownLeftAndUpRightToCenter')
```



| Illustration | DownLeftAndUpRightToCenter |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/DownLeftAndUpRightToCenter.png) | ![illustration for DownLeftAndUpRightToCenter](../../fontawesome-6/Solid/DownLeftAndUpRightToCenter.Local.png) |




## DownLeftAndUpRightToCenter

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element DownLeftAndUpRightToCenter
include('fontawesome-6/Solid/DownLeftAndUpRightToCenter')

' renders the element
DownLeftAndUpRightToCenter('DownLeftAndUpRightToCenter', 'Down Left And Up Right To Center', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element DownLeftAndUpRightToCenter
include('fontawesome-6/Solid/DownLeftAndUpRightToCenter')

' renders the element
DownLeftAndUpRightToCenter('DownLeftAndUpRightToCenter', 'Down Left And Up Right To Center', 'an optional tech label', 'an optional description')
@enduml
```
